var classFl__Text__Display =
[
    [ "Style_Table_Entry", "structFl__Text__Display_1_1Style__Table__Entry.html", "structFl__Text__Display_1_1Style__Table__Entry" ],
    [ "Fl_Text_Display", "classFl__Text__Display.html#a42c6300eda2d0eaca52d20f137530197", null ],
    [ "~Fl_Text_Display", "classFl__Text__Display.html#aa473b5387fd9f06daea61036b8271b05", null ],
    [ "absolute_top_line_number", "classFl__Text__Display.html#a28a7977a99ba473260863c7dcb3a6baa", null ],
    [ "buffer", "classFl__Text__Display.html#a41b157af52d071ae0df64a774ef4d853", null ],
    [ "buffer", "classFl__Text__Display.html#ae5a312a54d2f4bcbeb91e0ad76717eaa", null ],
    [ "buffer", "classFl__Text__Display.html#a0244a43078c78af8f528f933a6719490", null ],
    [ "calc_last_char", "classFl__Text__Display.html#ac1b0ca46ee02ec0c59d1df188fc48f7d", null ],
    [ "calc_line_starts", "classFl__Text__Display.html#af2d8e613a81bfea815288b9d77874b4b", null ],
    [ "clear_rect", "classFl__Text__Display.html#aaa87cfd0f3bf1975c38a38d5873e590a", null ],
    [ "col_to_x", "classFl__Text__Display.html#aa4c277bb4856da69b925ba4e47435c9f", null ],
    [ "count_lines", "classFl__Text__Display.html#a35933071176822679acdb00c449428d9", null ],
    [ "cursor_color", "classFl__Text__Display.html#a773052f561cd546dfc2d1c8fd5485dae", null ],
    [ "cursor_color", "classFl__Text__Display.html#a17bfc3af03f82c18c7ebb6ef34ed2139", null ],
    [ "cursor_style", "classFl__Text__Display.html#a6f4751931de885d4907e659d97acab30", null ],
    [ "display_insert", "classFl__Text__Display.html#ac5de2af1a6744d3f7be1fc7c53343f75", null ],
    [ "display_needs_recalc", "classFl__Text__Display.html#ae866a3c3130570ef61c632b7a0e2c43a", null ],
    [ "draw", "classFl__Text__Display.html#a2db0c8c740c19c6903a860fa3ceb9a4f", null ],
    [ "draw_cursor", "classFl__Text__Display.html#a5e5d522b89d167554ad059bc9a39b9b4", null ],
    [ "draw_line_numbers", "classFl__Text__Display.html#afc77f4bedb15408180b704a91252af80", null ],
    [ "draw_range", "classFl__Text__Display.html#a63df8b065f442f04eb0653318e048612", null ],
    [ "draw_string", "classFl__Text__Display.html#a707d8b4ce699d2c7950d8adb52aff9ce", null ],
    [ "draw_text", "classFl__Text__Display.html#a8a03d48ca14949b0a1933fbee2c0e347", null ],
    [ "draw_vline", "classFl__Text__Display.html#ad6288a3a93930c706c154ea065308c9d", null ],
    [ "empty_vlines", "classFl__Text__Display.html#a01978ca13b7ce6ad58067263cef1309c", null ],
    [ "extend_range_for_styles", "classFl__Text__Display.html#ade1e3e8a41e7b7bb2d2cd0141b494419", null ],
    [ "find_line_end", "classFl__Text__Display.html#ae925f0bbfe42a6dc649a1fac85c13dee", null ],
    [ "find_wrap_range", "classFl__Text__Display.html#a825d640ec72904f7fe27cae8881a0e5a", null ],
    [ "find_x", "classFl__Text__Display.html#a74d290bbc81bab4c98ca537955f3a82f", null ],
    [ "get_absolute_top_line_number", "classFl__Text__Display.html#a9496ca6e33b127a2f66ea1b2a1202151", null ],
    [ "grammar_underline_color", "classFl__Text__Display.html#a91e871bc1f1ba50fb19b3841bbf96058", null ],
    [ "grammar_underline_color", "classFl__Text__Display.html#ad96059453dbf1035e7e4f8ffed5c60ae", null ],
    [ "handle", "classFl__Text__Display.html#a97c837f06cfbaed3e7cdfc2e43f1089d", null ],
    [ "handle_rmb", "classFl__Text__Display.html#a7c9c4fb06430deb98091249362c1efbd", null ],
    [ "handle_vline", "classFl__Text__Display.html#a10713a9bb22e486887eeda7f75324389", null ],
    [ "hide_cursor", "classFl__Text__Display.html#a04ba6677e453106781e28f4fc75dcef8", null ],
    [ "highlight_data", "classFl__Text__Display.html#ae09d61739b737a32868ffe0295a25dec", null ],
    [ "in_selection", "classFl__Text__Display.html#a63b60d5fcb0fb09fc906ef9dc3c11e99", null ],
    [ "insert", "classFl__Text__Display.html#a9a813cdf8fd1f142882a4c8b6a9d2bbf", null ],
    [ "insert_position", "classFl__Text__Display.html#a8f02f5ee62ab03d8144765ef86d4ad01", null ],
    [ "insert_position", "classFl__Text__Display.html#aa18e615713b30b870045fc370758b510", null ],
    [ "line_end", "classFl__Text__Display.html#a51ccc5a2a4f52d1b63fbb71f853a2d62", null ],
    [ "line_start", "classFl__Text__Display.html#a3c400abedbed52884e2f7c4ecc236b3d", null ],
    [ "linenumber_align", "classFl__Text__Display.html#af391c9cc9def92f42ef4c6ded13f8370", null ],
    [ "linenumber_align", "classFl__Text__Display.html#a1856a46246f35556ef13b186e1609321", null ],
    [ "linenumber_bgcolor", "classFl__Text__Display.html#a28ebc88de67aa8aa1e9edb2cec132bfd", null ],
    [ "linenumber_bgcolor", "classFl__Text__Display.html#ae3f8bff6fb84f60064b7e4b8ac037787", null ],
    [ "linenumber_fgcolor", "classFl__Text__Display.html#ab06717a810ba7ae34dd04d016c47be1e", null ],
    [ "linenumber_fgcolor", "classFl__Text__Display.html#aa2215c44fd26defa382c8b13df93b183", null ],
    [ "linenumber_font", "classFl__Text__Display.html#aa8c310d79f422d98493c97c8b1b47616", null ],
    [ "linenumber_font", "classFl__Text__Display.html#acfdfde4e3a2edbaf662db3441ef1ad4e", null ],
    [ "linenumber_format", "classFl__Text__Display.html#a136a40f73fd402e11732ad704146a8d7", null ],
    [ "linenumber_format", "classFl__Text__Display.html#abd21dfb0bed631523170a3754575e95c", null ],
    [ "linenumber_size", "classFl__Text__Display.html#a4aecc6a7cc2e4ce9d36e277513725c8f", null ],
    [ "linenumber_size", "classFl__Text__Display.html#ab05046502525913981670a233d07a381", null ],
    [ "linenumber_width", "classFl__Text__Display.html#a82dc6b4b49e8e6cc0e41bcaed1bdb4d3", null ],
    [ "linenumber_width", "classFl__Text__Display.html#ab2d7774bcaf13fb00425c0b3e929522d", null ],
    [ "longest_vline", "classFl__Text__Display.html#af7349426259068b49166da670e1c348f", null ],
    [ "maintain_absolute_top_line_number", "classFl__Text__Display.html#a5cdad865b3cf584ac4e1f6c023361f40", null ],
    [ "maintaining_absolute_top_line_number", "classFl__Text__Display.html#a24fc4bf56dcd90af1308ea900fd9c0e8", null ],
    [ "measure_deleted_lines", "classFl__Text__Display.html#a6ad436a0dfea7f5f69476e570492873d", null ],
    [ "measure_proportional_character", "classFl__Text__Display.html#aff74d8254e23d1c80f32225b0688bc21", null ],
    [ "measure_vline", "classFl__Text__Display.html#a43b69af9661117884c07f4dba703ee73", null ],
    [ "move_down", "classFl__Text__Display.html#a1fe1ed3d39556253238235fd0a57d2bd", null ],
    [ "move_left", "classFl__Text__Display.html#a41c90322a2be857fb6362c783a9d3450", null ],
    [ "move_right", "classFl__Text__Display.html#a43532a8c0a8698087cb349b0b3e5f192", null ],
    [ "move_up", "classFl__Text__Display.html#a62d586abbef6563adbf06c40eaa71c7d", null ],
    [ "next_word", "classFl__Text__Display.html#abb9d0b39bfcb5724db615f328b3acd7a", null ],
    [ "offset_line_starts", "classFl__Text__Display.html#a5c79f7dacb4d5e15925a276876661620", null ],
    [ "overstrike", "classFl__Text__Display.html#ae612b71447f03a6ad1f46ae8c1cc9f38", null ],
    [ "position_style", "classFl__Text__Display.html#a50c7195b40f1168cdfdfce73a2d177d7", null ],
    [ "position_to_line", "classFl__Text__Display.html#a83735d562ec7ffbf3d381eefffc88089", null ],
    [ "position_to_linecol", "classFl__Text__Display.html#a772ace0180ebf38f2dc7b6402fd62501", null ],
    [ "position_to_xy", "classFl__Text__Display.html#a0bf0bfb6bb3ac9d6b4774b8a2b1849ec", null ],
    [ "previous_word", "classFl__Text__Display.html#a83c23e74c58e01e61259a6bbaf632ed3", null ],
    [ "recalc_display", "classFl__Text__Display.html#a2c2089df8e61ec00991abda79026f1fe", null ],
    [ "redisplay_range", "classFl__Text__Display.html#a6ec6a8ca047a45805522efbc301c786a", null ],
    [ "reset_absolute_top_line_number", "classFl__Text__Display.html#a29cca6a03ac20b1af20913c5a0e25fe7", null ],
    [ "resize", "classFl__Text__Display.html#ad0fb241ff581cc363271b6f960ec60c8", null ],
    [ "rewind_lines", "classFl__Text__Display.html#ab979d92ae92c3209cabd187028d61029", null ],
    [ "scroll", "classFl__Text__Display.html#aa6705c216c0626763f3f34d3e318d465", null ],
    [ "scroll_", "classFl__Text__Display.html#ac59b0199f494e20eae3fb270bd20b0f9", null ],
    [ "scrollbar_align", "classFl__Text__Display.html#a26f6e0b2a781f023d5a13b9bdd0af486", null ],
    [ "scrollbar_align", "classFl__Text__Display.html#a4b14388f53b951244edcfab51c2a1e18", null ],
    [ "scrollbar_size", "classFl__Text__Display.html#a6dc75e23d3fc181683118072436ba537", null ],
    [ "scrollbar_size", "classFl__Text__Display.html#a21bf730e770cf58a28cacdd2282d981b", null ],
    [ "scrollbar_width", "classFl__Text__Display.html#a0006a273fa0a2370e6db2d6aa079fcb6", null ],
    [ "scrollbar_width", "classFl__Text__Display.html#a461a7dc773676851db6031519fee1d7e", null ],
    [ "secondary_selection_color", "classFl__Text__Display.html#aa2c0ac920985d75fb269a7b93b8c6624", null ],
    [ "secondary_selection_color", "classFl__Text__Display.html#af26ffb470359b2301c6c385611969a6a", null ],
    [ "shortcut", "classFl__Text__Display.html#a98f01dd6b8be0522e54bccf0f3587d47", null ],
    [ "shortcut", "classFl__Text__Display.html#a3ec453b6dc9cc468619688c5bdf3dc95", null ],
    [ "show_cursor", "classFl__Text__Display.html#a2e19af56aacc79cbefe426ca6255099d", null ],
    [ "show_insert_position", "classFl__Text__Display.html#aadc28a301981f02edc3d57913f56b766", null ],
    [ "skip_lines", "classFl__Text__Display.html#adf4a0d3ffb4ebdd34954d1781516653c", null ],
    [ "spelling_underline_color", "classFl__Text__Display.html#aa3ea085c94d050410def6111a4551eb7", null ],
    [ "spelling_underline_color", "classFl__Text__Display.html#ae16f7a633f5500b2abc0237bad353871", null ],
    [ "string_width", "classFl__Text__Display.html#a033fb1323b0640601240829e845598f9", null ],
    [ "style_buffer", "classFl__Text__Display.html#acce0f152b6c18f0f4cf1d3d0e43a1a58", null ],
    [ "textcolor", "classFl__Text__Display.html#a8695a84858aa91aef4323f4618cab9b7", null ],
    [ "textcolor", "classFl__Text__Display.html#a2572e2a4e5bccd59fb94e46b1329e4cf", null ],
    [ "textfont", "classFl__Text__Display.html#aede1822b26480e2d08c3625b67f7abe3", null ],
    [ "textfont", "classFl__Text__Display.html#a8bcd59e82106e198bae05ca073cacdf1", null ],
    [ "textsize", "classFl__Text__Display.html#ad92e726e57de12916b1493ed2370177b", null ],
    [ "textsize", "classFl__Text__Display.html#a00f7c0a58a3efd71a8379762dd20c299", null ],
    [ "update_h_scrollbar", "classFl__Text__Display.html#a392b252cf45bc123e58c2542578637d7", null ],
    [ "update_line_starts", "classFl__Text__Display.html#af80c4c92503b0b713e666b9c1a9742f1", null ],
    [ "update_v_scrollbar", "classFl__Text__Display.html#a261e2e626a6448307fe718c7868b24d9", null ],
    [ "vline_length", "classFl__Text__Display.html#a0ee7456ef5ac0baa5819f67173aec83b", null ],
    [ "word_end", "classFl__Text__Display.html#a6fb0cd917979a537ba8e2142f0f9d7fc", null ],
    [ "word_start", "classFl__Text__Display.html#a593eb42b7c691417311b4cf75821a8f2", null ],
    [ "wrap_mode", "classFl__Text__Display.html#ab9378d48b949f8fc7da04c6be4142c54", null ],
    [ "wrap_uses_character", "classFl__Text__Display.html#a5da78184a39741a25a456ba1928c38dc", null ],
    [ "wrapped_column", "classFl__Text__Display.html#a9507d73613f6166a99283cacd7d2b0d7", null ],
    [ "wrapped_line_counter", "classFl__Text__Display.html#a9d2f815f11f77305e8f440c654372133", null ],
    [ "wrapped_row", "classFl__Text__Display.html#aafdfe5c72839546c6100edf6f35222f8", null ],
    [ "x_to_col", "classFl__Text__Display.html#a69139918fadc2ea30d5c16583fc8d0c8", null ],
    [ "xy_to_position", "classFl__Text__Display.html#a3048c33ca31c4ccb39ca6dff352aa47b", null ],
    [ "xy_to_rowcol", "classFl__Text__Display.html#ac2fd9e9ef877f35a20136b9a2be54553", null ]
];